spec_name=BP SQL FB2
spec_description=A set of Broadband Provisioner specific SQL SELECT statements for use with Firebird 2.x. Copyright (c) 2007-2022, Weird Solutions Inc. All rights reserved.
include=sqlinc

name=dhcp.name
group=general
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.NAME = ?)
description=Suitable for most DHCP persistent objects
cursor_num=3000

name=dhcp.oid
group=general
arg_names=OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.OID = ?)
description=Suitable for most DHCP persistent objects
cursor_num=3050

name=binding.maxaddr
group=binding
arg_names=
arg_types=
statement=SELECT MAX(T.IPADDR) FROM <<TABLE>>
description=Finds the generic address binding record with highest ip address value
cursor_num=3100

name=binding.minaddr
group=binding
arg_names=
arg_types=
statement=SELECT MIN(T.IPADDR) FROM <<TABLE>>
description=Finds the generic address binding record with lowest ip address value
cursor_num=3200

name=binding4.dom_bid_relay
group=binding
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,CLIENT_ID,RELAY
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND (T.CLIENT_ID=? OR T.CLIENT_ID='') AND (T.RELAY=? OR T.RELAY='255.255.255.255')) PLAN SORT (SORT (JOIN (T INDEX (IDX_ABINDINGS4_BID_RELAY),I INDEX (IDX_WSI_DOMAIN_ID_T)))) ORDER BY T.CLIENT_ID DESC
description=Select dhcpv4 address bindings matching domains/binding id/relay agent
cursor_num=3300

name=binding6.dom_bid_relay
group=binding
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,CLIENT_ID,IATYPE,IAID,RELAY
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__],[__DB_TYPE_UINT32__],[__DB_TYPE_UINT32__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND (T.CLIENT_ID=?) AND (T.IATYPE=?) AND (T.IAID=?) AND (T.RELAY=?))
description=Select dhcpv6 address bindings matching domains/binding id/relay agent
cursor_num=3400

name=binding4.dom_bid_addr
group=binding
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,CLIENT_ID,IPADDR
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND (T.CLIENT_ID=? OR T.CLIENT_ID='') AND (T.IPADDR=?)) PLAN SORT (SORT (JOIN (T INDEX (PK_ABINDINGS4_IPADDR),I INDEX (IDX_WSI_DOMAIN_ID_T)))) ORDER BY T.CLIENT_ID DESC
description=Select dhcpv4 address bindings matching domains/binding id/ip address
cursor_num=3500

name=binding6.dom_bid_addr
group=binding
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,CLIENT_ID,IATYPE,IAID,IPADDR
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__],[__DB_TYPE_UINT32__],[__DB_TYPE_UINT32__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND (T.CLIENT_ID=?) AND (T.IATYPE=?) AND (T.IAID=?) AND (T.IPADDR=?))
description=Select dhcpv6 address bindings matching domains/binding id/ip address
cursor_num=3600

name=binding.dom_addr
group=binding
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,IPADDR
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND (T.IPADDR = ?))
description=Select generic address bindings matching domains/ip address
cursor_num=3700

name=binding4.dom_bid
group=binding
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,CLIENT_ID
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND (T.CLIENT_ID = ?)) ORDER BY T.IPADDR ASC
description=Select dhcpv4 address bindings matching domains/binding id
cursor_num=3800

name=binding6.dom_bid
group=binding
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,CLIENT_ID,IATYPE,IAID
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__],[__DB_TYPE_UINT32__],[__DB_TYPE_UINT32__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND (T.CLIENT_ID = ? AND T.IATYPE = ? AND T.IAID = ?)) ORDER BY T.IPADDR ASC
description=Select dhcpv6 address bindings matching domains/binding id
cursor_num=3900

name=binding4.bid_relay
group=binding
arg_names=CLIENT_ID,RELAY
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.CLIENT_ID = ? AND T.RELAY = ?) ORDER BY T.IPADDR ASC
description=Select dhcpv4 address bindings matching binding id/relay agent
cursor_num=4000

name=binding6.bid_relay
group=binding
arg_names=CLIENT_ID,IATYPE,IAID,RELAY
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_UINT32__],[__DB_TYPE_UINT32__],[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.CLIENT_ID = ? AND T.IATYPE = ? AND T.IAID = ? AND T.RELAY = ?) ORDER BY T.IPADDR ASC
description=Select dhcpv6 address bindings matching binding id/relay agent
cursor_num=4100

name=binding.addr
group=binding
arg_names=IPADDR
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.IPADDR = ?)
description=Select generic address bindings matching ip address
cursor_num=4200

name=binding4.bid
group=binding
arg_names=CLIENT_ID
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.CLIENT_ID = ?) ORDER BY T.IPADDR ASC
description=Select dhcpv4 address bindings matching binding id
cursor_num=4300

name=binding6.bid
group=binding
arg_names=CLIENT_ID,IATYPE,IAID
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_UINT32__],[__DB_TYPE_UINT32__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.CLIENT_ID = ? AND T.IATYPE = ? AND T.IAID = ?) ORDER BY T.IPADDR ASC
description=Select dhcpv6 address bindings matching binding id
cursor_num=4400

name=binding.range
group=binding
arg_names=IP_ADDR_LOW,IP_ADDR_UP
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.IPADDR >= ? AND T.IPADDR <= ?) ORDER BY T.IPADDR ASC
description=Select generic address bindings within ip range low/high
cursor_num=4500

name=binding.count.type_tid
group=binding
arg_names=TID_TYPE,TID
arg_types=[__DB_TYPE_UINT32__],[__DB_TYPE_STRING__]
statement=SELECT COUNT(*) FROM <<TABLE>> WHERE (TID_TYPE = ? AND TID = ?)
function_name=COUNT
description=Count binding records matching tid type / tid
cursor_num=4600

name=binding.tid
group=binding
arg_names=TID,TID_TYPE
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_UINT32__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.TID = ? AND T.TID_TYPE = ?)
description=Select bindings with respect to their TID association.
cursor_num=4650

name=apool4.dom_relay
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,ADDR
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T JOIN wsi_domain_id I on (I.SRC_PK = T.PK) JOIN wsi_address A on ((A.SRC_PK = T.PK) AND (A.SRC_TABLE = 'dhcp_apools4')) WHERE ((<<DOMAIN_ID>>) AND (A.ADDR = ?)) PLAN SORT (SORT (JOIN (A INDEX (IDX_WSI_ADDRESS_ADDR),T INDEX (PK_APOOLS4),I INDEX (IDX_WSI_DOMAIN_ID_T)))) ORDER BY T.WEIGHT DESC
description=Select dhcpv4 address pools matching domain id/relay agent
cursor_num=4700

name=apool6.dom_relay
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,ADDR
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T JOIN wsi_domain_id I on (I.SRC_PK = T.PK) JOIN wsi_address A on ((A.SRC_PK = T.PK) AND (A.SRC_TABLE = 'dhcp_apools6')) WHERE ((<<DOMAIN_ID>>) AND (A.ADDR = ?)) PLAN SORT (SORT (JOIN (A INDEX (IDX_WSI_ADDRESS_ADDR),T INDEX (PK_APOOLS6),I INDEX (IDX_WSI_DOMAIN_ID_T)))) ORDER BY T.WEIGHT DESC
description=Select dhcpv6 address pools matching domain id/relay agent
cursor_num=4800

name=pool.dom
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>
arg_types=<<DOMAIN_ID>>
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>)) ORDER BY T.WEIGHT DESC
description=Select generic address pools matching domain id, ordered by weight
cursor_num=4900

name=pool.dom_prefix
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,PREFIX
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND T.PREFIX = ?) ORDER BY T.WEIGHT DESC
description=Select generic address pools matching domain id/prefix, ordered by weight
cursor_num=5000

name=pool.session_id
group=pool
arg_names=SESSION_ID
arg_types=[__DB_TYPE_INT32__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID = ?)
description=Select pools based on session_id.
cursor_num=5050

name=pool.dom_name
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,NAME
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND T.NAME = ?)
description=Select generic address pools matching domain id/name
cursor_num=5100

name=pool.dom_oid
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,OID
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND T.OID = ?)
description=Select generic address pools matching domain sat id/object id
cursor_num=5150

name=npool6.dom_relay
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,ADDR
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T JOIN wsi_domain_id I on (I.SRC_PK = T.PK) JOIN wsi_address A on ((A.SRC_PK = T.PK) AND (A.SRC_TABLE = 'dhcp_npools6')) WHERE ((<<DOMAIN_ID>>) AND (A.ADDR = ?)) PLAN SORT (SORT (JOIN (A INDEX (IDX_WSI_ADDRESS_ADDR),T INDEX (PK_NPOOLS6),I INDEX (IDX_WSI_DOMAIN_ID_T)))) ORDER BY T.WEIGHT DESC
description=Select dhcpv6 network pools matching domain id/relay agent
cursor_num=5200

name=policy.dom
group=policy
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>
arg_types=<<DOMAIN_ID>>
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) JOIN WSI_DOMAINS D ON (I.DOMAIN_ID = D.OID) WHERE (<<DOMAIN_ID>>) ORDER BY (D.PRIORITY) ASC
description=Select policies matching domain id, ordered by priority
cursor_num=5300

name=policy.name
group=policy
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T  WHERE (T.NAME = ?)
description=Select policies matching input name.
cursor_num=5350

name=option.tagpath_vid
group=option
arg_names=TAGPATH,VENDOR_ID
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.TAGPATH = ? AND T.VENDOR_ID = ?)
description=Select options matching tagpath/vendor id
cursor_num=5400

name=option.tagpath
group=option
arg_names=TAGPATH
arg_types=[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.TAGPATH = ?)
description=Select options matching tagpath
cursor_num=5500

name=vclass.vclass
group=vclass
arg_names=VCLASS
arg_types=[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.VCLASS = ?)
description=Select vendor classes matching vendor class
cursor_num=5600

name=vclass.vid
group=vclass
arg_names=VID
arg_types=[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.VID = ?)
description=Select vendor classes matching vendor id
cursor_num=5700

name=keyvalue.class_subclass_key_enabled
group=keyvalue
arg_names=KCLASS,SUBCLASS,KKEY
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.KCLASS = ? AND T.SUBCLASS = ? AND T.ENABLED = 1 AND T.KKEY LIKE ? ESCAPE '\')
description=Select 'enabled' (active) keyvalue records matching class/subclass/key
cursor_num=5800

name=domainid.id
group=secured_object
arg_names=DOMAIN_ID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.DOMAIN_ID = ?)
description=Select domain-ids matching domain id
cursor_num=5900

name=domain.name
group=domain
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.NAME = ?)
description=Select domains matching name
cursor_num=6100

name=domain.type
group=domain
arg_names=DOMAIN_TYPE
arg_types=[__DB_TYPE_INT32__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.DOMAIN_TYPE = ?)
description=Select domains matching its type (role_domain_type or device_domain_type).
cursor_num=6150

name=domain.group.name
group=domain
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.NAME = ?)
description=Select domains matching name
cursor_num=6160

name=domainnameid.name
group=domain
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.NAME = ?)
description=Select domain-name-ids matching name
cursor_num=6300

name=domainnameid.id
group=domain
arg_names=DOMAIN_ID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.DOMAIN_ID = ?)
description=Select domain-name-ids matching domain id
cursor_num=6325

name=domain_memberships.domainid
group=domain
arg_names=DOMAIN_ID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T JOIN wsi_domain_mships_links L ON (L.SRC_ATTR_REF = T.PK) JOIN wsi_domain_id DI ON (DI.PK = L.DEST_ATTR_REF) WHERE (DI.DOMAIN_ID = ?)
description=Select domain memberships where those have domain ID's as a member
cursor_num=6350

name=role.domain_name
group=role
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T JOIN wsi_domains D ON (T.DOMAIN_REF = D.PK) WHERE (D.NAME = ?)
description=Select roles matching the domain name of the domain it is associated with.
cursor_num=6360

name=role.domain_id
group=role
arg_names=OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T JOIN wsi_domains D ON (T.DOMAIN_REF = D.PK) WHERE (D.OID = ?)
description=Select roles matching the domain ID of the domain it is associated with.
cursor_num=6370

name=role.id
group=role
arg_names=OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.OID = ?)
description=Select roles matching its own identity.
cursor_num=6380

name=accesscontrol.accessid
group=access_control
arg_names=ACCESS_ID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.ACCESS_ID = ?)
description=Select access controls matching access id
cursor_num=6400

name=accesscontrol.domainid
group=access_control
arg_names=DOMAIN_ID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.DOMAIN_ID = ?)
description=Select access controls matching domain id
cursor_num=6500

name=accesscontrol.accessids
group=access_control
generic_args=ACCESS_ID
arg_names=<<ACCESS_ID>>
arg_types=<<ACCESS_ID>>
statement=SELECT A.* FROM <<TABLE>> A WHERE (<<ACCESS_ID>>)
description=Select access controls matching access ids
cursor_num=6600

name=accesscontrol.domainid_accessid
group=access_control
arg_names=DOMAIN_ID,ACCESS_ID
arg_types=[__DB_TYPE_LONG__],[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.DOMAIN_ID = ? AND T.ACCESS_ID = ?)
description=Select access control matching domain id/access id
cursor_num=6700

name=device_account.name_class
group=device_account
arg_names=NAME,ACLASS
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.NAME = ? AND T.ACLASS = ?)
description=Select account matching name/class
cursor_num=6800

name=user_account.name
group=user_account
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.NAME = ?)
description=Select account matching name
cursor_num=6900

name=packet.primaryid
group=packet
arg_names=PRIMARY_ID
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.PRIMARY_ID = ?)
description=Select historical packets using a primary identifier
cursor_num=7000

name=packet.primaryid_type
group=packet
arg_names=PRIMARY_ID,PKT_TYPE
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.PRIMARY_ID = ? AND T.PKT_TYPE = ?)
description=Select historical packets using a primary identifier and packet type
cursor_num=7100

name=packet.secondaryid
group=packet
arg_names=SECONDARY_ID
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SECONDARY_ID = ?)
description=Select historical packets using a secondary identifier
cursor_num=7200

name=packet.rid
group=packet
arg_names=RID
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.RID = ?)
description=Select historical packets using the RID
cursor_num=7250

name=packet.cid
group=packet
arg_names=CID
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.CID = ?)
description=Select historical packets using the CID
cursor_num=7300

name=packet.sid
group=packet
arg_names=SID
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SID = ?)
description=Select historical packets using the SID
cursor_num=7350

name=pending4.bid_relay
group=pending
arg_names=CLIENT_ID,RELAY
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.CLIENT_ID = ? AND T.RELAY = ?)
description=Select dhcpv4 pendings matching binding id/relay agent
cursor_num=7400

name=pending6.bid_relay
group=pending
arg_names=CLIENT_ID,IATYPE,IAID,RELAY
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_UINT32__],[__DB_TYPE_UINT32__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.CLIENT_ID = ? AND T.IATYPE = ? AND T.IAID = ? AND T.RELAY = ?)
description=Select dhcpv6 pendings matching binding id/relay agent
cursor_num=7500

name=pending.min_age
group=pending
arg_names=OFFER_TIME
arg_types=[__DB_TYPE_INT64__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.OFFER_TIME <= ?)
description=Select all pending records older than the given age, no security check
cursor_num=7600

name=pending.pool_oid
group=pending
arg_names=POOL_OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.POOL_OID = ?)
description=Select all pending records matching specified pool oid.
cursor_num=7700

name=tftp_policy.dom
group=tftp_policy
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>
arg_types=<<DOMAIN_ID>>
statement=SELECT DISTINCT T.* FROM <<TABLE>> T JOIN wsi_domain_id I ON (T.PK = I.SRC_PK) WHERE ((<<DOMAIN_ID>>) AND T.ENABLED = 1)
description=Select 'enabled' (active) packages matching domain id, ordered by sequence number
cursor_num=7800

name=binding.pool_expired
group=binding
arg_names=T1,T2,POOL_OID
arg_types=[__DB_TYPE_INT64__],[__DB_TYPE_INT64__],[__DB_TYPE_LONG__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.LEASE_EXPIRE >= ? AND T.LEASE_EXPIRE <= ? AND T.POOL_OID = ?) ORDER BY T.LEASE_EXPIRE ASC
description=Select expired bindings within timeframe for a specific pool, oldest first
cursor_num=7900

name=binding.pool_oid
group=binding
arg_names=POOL_OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.POOL_OID = ?)
description=Select all bindings from a specific pool.
cursor_num=7950

name=binding.expired
group=binding
arg_names=T1,T2
arg_types=[__DB_TYPE_INT64__],[__DB_TYPE_INT64__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.LEASE_EXPIRE >= ? AND T.LEASE_EXPIRE <= ?) ORDER BY T.LEASE_EXPIRE ASC
description=Select expired bindings within timeframe, oldest first
cursor_num=8000

name=binding.pool_oid_with_oid_paging
group=binding
arg_names=POOL_OID,OID
arg_types=[__DB_TYPE_LONG__],[__DB_TYPE_LONG__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.POOL_OID = ? AND T.OID >= ?) ORDER BY T.OID
description=Select all bindings from a specific pool equipped with a primitive paging.
cursor_num=8050

name=npool4.dom_relay
group=pool
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,ADDR
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T JOIN wsi_domain_id I on (I.SRC_PK = T.PK) JOIN wsi_address A on ((A.SRC_PK = T.PK) AND (A.SRC_TABLE = 'dhcp_npools4')) WHERE ((<<DOMAIN_ID>>) AND (A.ADDR = ?)) PLAN SORT (SORT (JOIN (A INDEX (IDX_WSI_ADDRESS_ADDR),T INDEX (PK_NPOOLS4),I INDEX (IDX_WSI_DOMAIN_ID_T)))) ORDER BY T.WEIGHT DESC
description=Select dhcpv4 network pools matching domain id/relay agent
cursor_num=8100

name=npool_mark.pool_oid
group=poolmark
arg_names=POOL_OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.POOL_OID = ?)
description=Select all network pool marker records matching specified pool oid.
cursor_num=8200

name=apool_mark.pool_oid
group=poolmark
arg_names=POOL_OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.POOL_OID = ?)
description=Select all address pool marker records matching specified pool oid.
cursor_num=8300

name=query.dom_name
group=query
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,NAME
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T JOIN wsi_domain_id I on (I.SRC_PK = T.PK) WHERE ((<<DOMAIN_ID>>) AND (T.NAME = ?)) ORDER BY T.NAME
description=Select query objects based on their names
cursor_num=8400

name=query.dom_identity
group=query
generic_args=DOMAIN_ID
arg_names=<<DOMAIN_ID>>,OID
arg_types=<<DOMAIN_ID>>,[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* from <<TABLE>> T JOIN wsi_domain_id I on (I.SRC_PK = T.PK) WHERE ((<<DOMAIN_ID>>) AND (T.OID = ?)) ORDER BY T.OID
description=Select query objects matching object identifier
cursor_num=8500

name=query.name
group=query
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T  WHERE (T.NAME = ?) ORDER BY T.NAME
description=Select query objects based on their names
cursor_num=8600

name=query.identity
group=query
arg_names=OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* from <<TABLE>> T WHERE (T.OID = ?) ORDER BY T.OID
description=Select query objects matching object identifier
cursor_num=8700

name=query.name_oid
group=query
arg_names=NAME,OID
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* from <<TABLE>> T  WHERE ((T.NAME = ?) OR (T.OID = ?)) ORDER BY T.NAME
description=Select query objects based on their name and oid.
cursor_num=8750

name=query.arg_name
group=query_arg
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T WHERE (T.NAME = ?) ORDER BY T.NAME
description=Select query argument objects based on their names
cursor_num=8800

name=query.target_name
group=query_arg
arg_names=NAME
arg_types=[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* from <<TABLE>> T WHERE (T.NAME = ?) ORDER BY T.NAME
description=Select target classes based on their names
cursor_num=8900

name=capability.role
group=capability
arg_names=ROLE_ID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.ROLE_ID = ?)
description=Select the capabilities that match a security token. I.e. a set of domain IDs.
cursor_num=9000

name=capability.role_class
group=capability
arg_names=ROLE_ID,TARGET_CLASS_NAME
arg_types=[__DB_TYPE_LONG__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T  WHERE ((T.ROLE_ID = ?) AND (T.TARGET_CLASS_NAME = ?))
description=Select the capabilities that match role ID and target class name.
cursor_num=9100

name=rule.priority
group=rule
arg_names=
arg_types=
statement=SELECT DISTINCT T.* FROM <<TABLE>> T ORDER BY T.PRI ASC
description=Select rules in priority order
cursor_num=9200

name=keyvalue.class_subclass
group=keyvalue
arg_names=KCLASS,SUBCLASS
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.KCLASS = ? AND T.SUBCLASS = ?)
description=Select keyvalue records matching class/subclass, regardless of 'enabled' state
cursor_num=9300

name=keyvalue.class_subclass_key
group=keyvalue
arg_names=KCLASS,SUBCLASS,KKEY
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT * FROM <<TABLE>> T WHERE (T.KCLASS = ? AND T.SUBCLASS = ? AND T.KKEY = ?)
description=Select keyvalue records matching class/subclass/key
cursor_num=9400

name=sample.storage
group=snmp_sample
arg_names=NAME,ACLASS,OBJECT_NAME,PREFIX_NAME
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT DISTINCT T.* FROM <<TABLE>> T WHERE (T.NAME = ? AND T.ACLASS = ? AND T.OBJECT_NAME = ? AND T.PREFIX_NAME = ?) ORDER BY T.MOD_TIME ASC
description=Select samples for the specified snmp object id ordered by oldest first
cursor_num=9500

name=sample.all.latest
group=snmp_sample
arg_names=ACLASS,OBJECT_NAME,PREFIX_NAME
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.ACLASS = ? AND S.OBJECT_NAME = ? AND S.PREFIX_NAME = ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
description=Select the most recent version of a given sample for all devices of the given class
cursor_num=9600

name=sample.count.device
group=snmp_sample
arg_names=NAME,ACLASS,OBJECT_NAME,PREFIX_NAME
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT COUNT(*) FROM <<TABLE>> T WHERE (T.NAME = ? AND T.ACLASS = ? AND T.OBJECT_NAME = ? AND T.PREFIX_NAME = ?)
function_name=COUNT
description=Count samples matching device/class/prefix/object
cursor_num=9700

name=sample.prefix.latest
group=snmp_sample
arg_names=NAME,ACLASS,PREFIX_NAME
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.NAME = ? AND S.ACLASS = ? AND S.PREFIX_NAME = ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
description=Select the most recent version of all samples for a given device and class
cursor_num=9800

name=sample.ivalue.range.in
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,LOW,HIGH
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__],[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND S.IVALUE >= ? AND S.IVALUE <= ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
description=Select the latest samples of prefix::object for all devices where ivalue is within the specified range (inclusive). Timeouts are excluded.
cursor_num=9900

name=sample.count.ivalue.range.in
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,LOW,HIGH
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__],[__DB_TYPE_LONG__]
statement=SELECT COUNT(*) FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND S.IVALUE >= ? AND S.IVALUE <= ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
function_name=COUNT
description=Count the latest samples of prefix::object for all devices where ivalue is within the specified range (inclusive). Timeouts are excluded.
cursor_num=15000

name=sample.ivalue.range.out
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,LOW,HIGH
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__],[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND (S.IVALUE < ? OR S.IVALUE > ?)) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
description=Select the latest samples of prefix::object for all devices where ivalue is outside the specified range (exclusive). Timeouts are excluded.
cursor_num=15100

name=sample.count.ivalue.range.out
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,LOW,HIGH
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__],[__DB_TYPE_LONG__]
statement=SELECT COUNT(*) FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND (S.IVALUE < ? OR S.IVALUE > ?)) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
function_name=COUNT
description=Count the latest samples of prefix::object for all devices where ivalue is outside the specified range (exclusive). Timeouts are excluded.
cursor_num=15200

name=sample.ivalue.under
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,LOW
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND S.IVALUE < ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
description=Select the latest samples of prefix::object for all devices where ivalue is less than the specified value. Timeouts are excluded.
cursor_num=15300

name=sample.count.ivalue.under
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,LOW
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__]
statement=SELECT COUNT(*) FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND S.IVALUE < ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
function_name=COUNT
description=Count the latest samples of prefix::object for all devices where ivalue is less than the specified value. Timeouts are excluded.
cursor_num=15400

name=sample.ivalue.over
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,HIGH
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND S.IVALUE > ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
description=Select the latest samples of prefix::object for all devices where ivalue is greater than the specified value. Timeouts are excluded.
cursor_num=15500

name=sample.count.ivalue.over
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME,HIGH
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_LONG__]
statement=SELECT COUNT(*) FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT != 1 AND S.IVALUE > ?) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
function_name=COUNT
description=Count the latest samples of prefix::object for all devices where ivalue is greater than the specified value. Timeouts are excluded.
cursor_num=15600

name=sample.timeout
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT = 1) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
description=Select the latest samples of prefix::object for all devices where the the device did not respond.
cursor_num=15700

name=sample.count.timeout
group=snmp_sample
arg_names=OBJECT_NAME,PREFIX_NAME
arg_types=[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT COUNT(*) FROM <<TABLE>> T NATURAL JOIN (SELECT DISTINCT S.OBJECT_NAME, S.PREFIX_NAME, S.NAME, MAX(S.MOD_TIME) AS MOD_TIME FROM <<TABLE>> S WHERE (S.OBJECT_NAME = ? AND S.PREFIX_NAME = ? AND S.TIMEOUT = 1) GROUP BY NAME,OBJECT_NAME,PREFIX_NAME);
function_name=COUNT
description=Select the latest samples of prefix::object for all devices where the the device did not respond.
cursor_num=15800
