spec_name=FAILOVER SQL FB2
spec_description=A set of SQL SELECT statements for tables private to the failover module.

name=afbinding.addr_only
group=fbinding
arg_names=IPADDR
arg_types=[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.IPADDR=?)
description=Select dhcpv4 failover binding record based on just the IP address.
cursor_num=10000

name=afbinding.addr
group=fbinding
arg_names=SESSION_ID,IPADDR
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.IPADDR=?)
description=Select dhcpv4 failover binding record based on session and IP address.
cursor_num=10050

name=afbinding.unacked
group=fbinding
arg_names=SESSION_ID,UPDATE_STATUS
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.UPDATE_STATUS=?) ORDER BY T.IPADDR ASC
description=Select dhcpv4 failover binding records based on whether the latest BNDUPD applied has been acked by peer with a BNDACK.
cursor_num=10100

name=afbinding.unacked.paging
group=fbinding
arg_names=SESSION_ID,UPDATE_STATUS,IPADDR
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.UPDATE_STATUS=? AND T.IPADDR >= ?) ORDER BY T.IPADDR ASC
description=Select dhcpv4 failover binding records based on whether the latest BNDUPD appliedd has been acked by peer with a BNDACK.
cursor_num=10150

name=afbinding.all
group=fbinding
arg_names=SESSION_ID
arg_types=[__DB_TYPE_INT32__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=?) ORDER BY T.IPADDR ASC
description=Select all dhcpv4 failover binding records for specified session.
cursor_num=10200

name=afbinding.all.paging
group=fbinding
arg_names=SESSION_ID,IPADDR
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.IPADDR >= ?) ORDER BY T.IPADDR ASC
description=Select all dhcpv4 failover binding records for specified session.
cursor_num=10250

name=afbinding.state
group=fbinding
arg_names=SESSION_ID,STATE
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.STATE =? )
description=Select all dhcpv4 failover binding records for specified session and binding state.
cursor_num=10300

name=afbinding.state_unacked
group=fbinding
arg_names=SESSION_ID,STATE,UPDATE_STATUS
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.STATE =? AND T.UPDATE_STATUS=? )
description=Select all dhcpv4 failover binding records for specified session, binding state and update status(ACKED/UNACKED)
cursor_num=10330

name=afbinding.pool_state
group=fbinding
arg_names=SESSION_ID,POOL_OID,STATE
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_LONG__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.POOL_OID =? AND T.STATE =? )
description=Select all dhcpv4 failover binding records for specified session, pool and binding state.
cursor_num=10350

name=afbinding.pool_state_unacked
group=fbinding
arg_names=SESSION_ID,POOL_OID,STATE,UPDATE_STATUS
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_LONG__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.POOL_OID =? AND T.STATE =? AND T.UPDATE_STATUS =?)
description=Select all dhcpv4 failover binding records for specified session, pool, binding state and update status (ACKED/UNACKED).
cursor_num=10351

name=afbinding.rangestate
group=fbinding
arg_names=SESSION_ID,STATE,IP_ADDR_LOW,IP_ADDR_UP
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.STATE =? AND T.IPADDR >=? AND T.IPADDR<=?)
description=Select all dhcpv4 failover binding records for specified session, binding state and within a range.
cursor_num=10400

name=afbinding.range_unacked_state
group=fbinding
arg_names=SESSION_ID,STATE,UPDATE_STATUS,IP_ADDR_LOW,IP_ADDR_UP
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__],[__DB_TYPE_STRING__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.STATE =? AND T.UPDATE_STATUS =? AND T.IPADDR >=? AND T.IPADDR<=?)
description=Select all dhcpv4 failover binding records for specified session, binding state, ack status and within a range.
cursor_num=10500

name=afbinding.pool_oid
group=fbinding
arg_names=POOL_OID
arg_types=[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.POOL_OID=? )
description=Select all dhcpv4 failover bindings that match a pool.
cursor_num=10600

name=afbinding.pool_oid_orphaned
group=fbinding
arg_names=POOL_OID,ORPHANED
arg_types=[__DB_TYPE_LONG__],[__DB_TYPE_BOOL__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.POOL_OID=? AND T.ORPHANED=?)
description=Select all dhcpv4 failover bindings that match a pool and whether it is orphaned or not.
cursor_num=10700

name=afbinding.underlying
group=fbinding
arg_names=SESSION_ID,UNDERLYING_OID
arg_types=[__DB_TYPE_INT32__],[__DB_TYPE_LONG__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=? AND T.UNDERLYING_OID=?)
description=Select the failover binding that match the session and the OID of the real binding.
cursor_num=10800

name=fail_config.session_id
group=fail_config
arg_names=SESSION_ID
arg_types=[__DB_TYPE_INT32__]
statement=SELECT T.* FROM <<TABLE>> T WHERE (T.SESSION_ID=?)
description=Select's the configuration record for a session ID.
cursor_num=10900
